Derives Upgradeable a) implements the interface; requires only the auth
to be defined b) sets wasm version by taking the version from Cargo.tomlDerives UpgradeableMigratable when both an upgrade and a migration are
needed a) implements the interface; requires the auth and the migration
logic to be defined b) sets wasm version by taking the version from
Cargo.toml